aboutsummaryrefslogtreecommitdiffhomepage
path: root/Eigen/src/Core/Flagged.h
diff options
context:
space:
mode:
Diffstat (limited to 'Eigen/src/Core/Flagged.h')
-rw-r--r--Eigen/src/Core/Flagged.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/Eigen/src/Core/Flagged.h b/Eigen/src/Core/Flagged.h
index 7cd042918..754eaf6c5 100644
--- a/Eigen/src/Core/Flagged.h
+++ b/Eigen/src/Core/Flagged.h
@@ -132,7 +132,7 @@ MatrixBase<Derived>::marked() const
/** \deprecated use MatrixBase::noalias()
*
* \returns an expression of *this with the MayAliasBit flag removed.
*
* Example: \include MatrixBase_lazy.cpp
* Output: \verbinclude MatrixBase_lazy.out
@@ -140,7 +140,7 @@ MatrixBase<Derived>::marked() const
* \sa class Flagged, marked()
*/
template<typename Derived>
-inline const Flagged<Derived, 0, MayAliasBit>
+inline const Flagged<Derived, 0, EvalBeforeAssigningBit>
MatrixBase<Derived>::lazy() const
{
return derived();
@@ -132,7 +132,7 @@ MatrixBase<Derived>::marked() const
/** \deprecated use MatrixBase::noalias()
*
- * \returns an expression of *this with the MayAliasBit flag removed.
+ * \returns an expression of *this with the EvalBeforeAssigningBit flag removed.
*
* Example: \include MatrixBase_lazy.cpp